==> apache-cxf-3.6.3-src.zip: apache-cxf-3.6.3-src/distribution/src/main/release/samples/jaxws_graalvm_dynamic/server/src/main/java/demo/jaxws/server/Server.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package demo.jaxws.server;


import javax.xml.ws.Endpoint;

import org.apache.cxf.Bus;
import org.apache.cxf.BusFactory;
import org.apache.cxf.bus.extension.ExtensionManagerBus;

public class Server {
    protected Server() throws Exception {
        System.out.println("Starting AddNumbers Server");
        
        final Bus bus = new ExtensionManagerBus(); 
        BusFactory.setDefaultBus(bus);
        
        Object implementor = new AddNumbersImpl();
        String address = "http://localhost:9000/handlers/AddNumbersService/AddNumbersPort";
        
        Endpoint.publish(address, implementor);
    }

    public static void main(String[] args) throws Exception {
        new Server();
        System.out.println("Server ready...");

        Thread.sleep(5 * 60 * 1000);
        System.out.println("Server exiting");
        System.exit(0);
    }
}

==> apache-cxf-4.1.3-src.zip: apache-cxf-4.1.3-src/distribution/src/main/release/samples/jaxws_graalvm_dynamic/server/src/main/java/demo/jaxws/server/Server.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package demo.jaxws.server;


import jakarta.xml.ws.Endpoint;

import org.apache.cxf.Bus;
import org.apache.cxf.BusFactory;
import org.apache.cxf.bus.extension.ExtensionManagerBus;

public class Server {
    protected Server() throws Exception {
        System.out.println("Starting AddNumbers Server");
        
        final Bus bus = new ExtensionManagerBus(); 
        BusFactory.setDefaultBus(bus);
        
        Object implementor = new AddNumbersImpl();
        String address = "http://localhost:9000/handlers/AddNumbersService/AddNumbersPort";
        
        Endpoint.publish(address, implementor);
    }

    public static void main(String[] args) throws Exception {
        new Server();
        System.out.println("Server ready...");

        Thread.sleep(5 * 60 * 1000);
        System.out.println("Server exiting");
        System.exit(0);
    }
}
